==> GNUMail-1.0.3.tar.gz: GNUMail/Bundles/PGP/PGPController.h <==
/*
**  PGPController.h
**
**  Copyright (c) 2001, 2002
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#import <AppKit/AppKit.h>

#import "GNUMailBundle.h"
#import "PreferencesModule.h"

#define NOT_ENCRYPTED 0
#define ENCRYPTED 1

#define NOT_SIGNED 0
#define SIGNED 2

@class Part;

@interface PGPController : NSObject <GNUMailBundle>
{
  // UI elements for our viewing and compose view
  NSButton *encrypt, *sign;  
  NSView *superview;

  NSImageCell *imageCell;
  
  // ivars
  id owner;

  NSString *resourcePath;
  
  NSMutableDictionary *passphraseCache;
}

//
// action methods
//
- (IBAction) encryptClicked: (id) sender;
- (IBAction) signClicked: (id) sender;

@end


//
// Private methods
//
@interface PGPController (Private)

- (BOOL) _analyseTaskOutput: (NSMutableData *) theMutableData
		     userID: (NSString *) theUserID 
                    message: (NSMutableString *) theMessage;

- (void) _decryptPart: (Part *) thePart
            multipart: (BOOL) aBOOL
              message: (Message *) theMessage;

- (Message *) _encryptMessage: (Message *) theMessage
                    multipart: (BOOL) aBOOL;

- (NSString *) _passphraseForID: (NSString *) theID;

- (void) _replaceCRLFInMutableData: (NSMutableData *) theMutableData;

@end

==> GNUMail-1.2.0pre1.tar.gz: GNUMail/Bundles/PGP/PGPController.h <==
/*
**  PGPController.h
**
**  Copyright (c) 2001-2004
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _GNUMail_H_PGPController
#define _GNUMail_H_PGPController

#import <AppKit/AppKit.h>

#include "GNUMailBundle.h"
#include "PreferencesModule.h"

#define NOT_ENCRYPTED 0
#define ENCRYPTED 1

#define NOT_SIGNED 0
#define SIGNED 2

#define SIGNED_AND_ENCRYPTED 3

@class CWMessage;
@class PGPImageView;

//
// PGPController class;
//
@interface PGPController : NSObject <GNUMailBundle>
{
  // UI elements for our viewing and compose view
  NSButton *encrypt, *sign;  
  NSView *superview;

  NSImage *sImage, *eImage, *seImage;
  PGPImageView *view;

  // ivars
  NSMutableDictionary *passphraseCache;
  NSString *resourcePath;
  NSTimer *timer;
  id owner;
}


//
// action methods
//
- (IBAction) encryptClicked: (id) sender;
- (IBAction) signClicked: (id) sender;

//
// other methods
//
- (void) updateAndRestartTimer;

@end

#endif // _GNUMail_H_PGPController
